# frozen_string_literal: true

require 'thor'

# Yadecli Cli Application
module Yadecli
  module Cli

    # Application
    class Application < Thor

      class_option 'verbose', type: :boolean, default: false

      desc 'version', 'Print Version'
      def version
        puts Yadecli::VERSION
      end

      desc 'status', 'Print Version'
      def status
        client = Yade::Client::ApplicationStatusClient.new
        client.get
      end

      desc 'connect URL', 'Connect to a yade backend'
      def connect(yade_url)
        CliUtil.print_header('Yade Connect',
                             ["Going to connect to yade backend", ''])

        outcome = Yadecli::Command::ConnectCommand.run(yade_url: yade_url)

        CliUtil.print_command_outcome(outcome)
      end

      desc 'login AUTH_URL USERNAME PASSWORD', 'Login to a yade'
      def login(auth_url, username, password)
        CliUtil.print_header('Yade Login',
                             ["Going to log in user #{username}", ''])

        outcome = Yadecli::Command::LoginCommand.run(auth_url: auth_url, auth_username: username, auth_password: password)

        CliUtil.print_command_outcome(outcome)
      end

      desc 'host TYPE', 'Manage hosts'
      subcommand 'host', Yadecli::Cli::Host

      desc 'project TYPE', 'Manage projects'
      subcommand 'project', Yadecli::Cli::Project

      desc 'module TYPE', 'Manage modules'
      subcommand 'module', Yadecli::Cli::Module

      desc 'task TYPE', 'Manage build tasks'
      subcommand 'task', Yadecli::Cli::Task

      desc 'composer TYPE', 'Manage composer projects'
      subcommand 'composer', Yadecli::Cli::Composer
    end
  end
end