# frozen_string_literal: true

require 'thor'

module Yadecli
  module Cli
    # Host
    class Host < Thor

      desc 'list', 'List available Yade hosts'
      def list
        CliUtil.print_header'Yade list hosts',
                            ['This are the available hosts', '']

        outcome = Yadecli::Command::Host::HostListCommand.run

        CliUtil.print_command_outcome(outcome)
      end

      desc 'bootstrap', 'Bootstrap a Yade host to prepare it for provisioning'
      method_option :setup, default: true, aliases: '-s', desc: 'Setup Yade bootstrap repository on host and install plugins'
      def bootstrap(host_fqdn)
        CliUtil.print_header'Yade bootstrap host',
                            ["Going to bootstrap Yade host #{host_fqdn}", '']

        outcome = Yadecli::Command::Host::HostBootstrapCommand.run(host_fqdn: host_fqdn, options: options)

        CliUtil.print_command_outcome(outcome)
      end

      desc 'provision', 'Provision a Yade host'
      def provision(host_fqdn)
        CliUtil.print_header'Yade provision host',
                            ["Going to provision Yade host #{host_fqdn}", '']

        outcome = Yadecli::Command::Host::HostProvisionCommand.run(host_fqdn: host_fqdn, options: options)

        CliUtil.print_command_outcome(outcome)
      end
    end
  end
end