# frozen_string_literal: true

require 'thor'

module Yadecli
  module Cli

    # Build
    class Module < Thor

      desc 'list', 'List available modules'
      def list(project_name)
        CliUtil.print_header'YadeCli List Modules', ["This are the available modules for the Yade project #{project_name}", '']

        outcome = Yadecli::Command::Module::ModuleListCommand.run(project_name: project_name)

        CliUtil.print_command_outcome(outcome)
      end

      desc 'install', 'Install a module for the project given by name'
      method_option :yes, aliases: '-y', desc: 'Answering yes to all question, will do a update if module already installed'
      method_option :all, aliases: '-a', desc: 'Install all modules of the project'
      def install(project_name, *module_names)
        CliUtil.print_header'YadeCli Install Module',
                            ["Going to install module #{module_names.join(', ')} for Yade project #{project_name}"]

        outcome = Yadecli::Command::Module::ModuleInstallCommand.run(project_name: project_name,
                                                                     module_names: module_names, options: options)

        CliUtil.print_command_outcome(outcome)
      end

    end
  end
end