# frozen_string_literal: true

require 'thor'

module Yadecli
  module Cli

    # Build
    class Project < Thor

      desc 'list', 'List available projects'
      def list
        CliUtil.print_header'YadeCli Projects', ['This are the available Yade projects', '']

        outcome = Yadecli::Command::Project::ProjectListCommand.run

        CliUtil.print_command_outcome(outcome)
      end

      desc 'install', 'Install a project'
      method_option :yes, aliases: '-y', desc: 'Answering yes to all question, will do a update if project already installed'
      def install(project_name)
        CliUtil.print_header'YadeCli Install Project',
                            ["Going to install Yade project #{project_name}", '']

        outcome = Yadecli::Command::Project::ProjectInstallCommand.run(project_name: project_name, options: options)

        CliUtil.print_command_outcome(outcome)
      end

      desc 'uninstall', 'Uninstall a project'
      method_option :yes, aliases: '-y', desc: 'Answering yes to all question, will do a unattended uninstall'
      def uninstall(project_name)
        CliUtil.print_header'YadeCli Uninstall Project',
                            ["Going to uninstall Yade project #{project_name}", '']

        outcome = Yadecli::Command::Project::ProjectUninstallCommand.run(project_name: project_name, options: options)

        CliUtil.print_command_outcome(outcome)
      end

      desc 'setup', 'Setup a project'
      def setup(project_name)
        CliUtil.print_header'YadeCli Project Setup',
                            ["Going to setup Yade project #{project_name}"]

        outcome = Yadecli::Command::Project::ProjectSetupCommand.run(project_name: project_name, options: options)

        CliUtil.print_command_outcome(outcome)
      end

      desc 'start', 'Start a project'
      def start(project_name, selection = nil)
        CliUtil.print_header'YadeCli Project Start',['Going to start Yade Project']

        outcome = Yadecli::Command::Project::ProjectStartCommand.run(project_name: project_name, selection: selection,
                                                                     options: options)

        CliUtil.print_command_outcome(outcome)
      end

    end
  end
end