# frozen_string_literal: true

require 'mutations'
require 'tty-table'

module Yadecli
  module Command
    module Composer
      class ComposerListCommand < Mutations::Command

        #
        def execute
          composer_project_client = Yade::Composer::Rest::Client::ComposerProjectClient.new
          composer_service_client = Yade::Composer::Rest::Client::ComposerServiceClient.new

          composer_projects = composer_project_client.list

          # print table
          table = TTY::Table.new header: ['Id', 'Name', 'Services', 'Installed', 'Branches', 'Git Url']

          # add as rows to table
          composer_projects.each do |p|
            project_id = p.id
            project_name = p.name
            project_installed = p.installed?

            composer_services = composer_service_client.get_by_composer_project_id(project_id)
            service_names = composer_services.collect(&:name).join(', ')

            gitlab_client = Yadecli::Client::GitlabClient.new

            branches = gitlab_client.get_branch_names(p.git_repo_name)
            default_branch = gitlab_client.get_default_branch(p.git_repo_name)

            if project_installed
              current_branch = FileUtil.git_current_branch(p.install_dir)
            else
              current_branch = nil
            end

            branches = branches.map do |b|
              if b == default_branch && b == current_branch
                "#{b} (Default, Current)"
              elsif b == default_branch && b != current_branch
                "#{b} (Default)"
              elsif b == current_branch && b != default_branch
                "#{b} (Current)"
              else
                b
              end
            end

            table << [project_id, project_name, service_names , project_installed, branches.join(', '), p.gitUrl]
          end

          renderer = TTY::Table::Renderer::ASCII.new(table, padding: [0, 1])

          renderer.render
        end
      end
    end
  end
end