# frozen_string_literal: true

require 'mutations'

module Yadecli
  module Command
    module Composer
      class ComposerLogCommand < Mutations::Command

        required do
          string :project_name, empty: false
          string :service_name, empty: false
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          composer_project_client = Yade::Composer::Rest::Client::ComposerProjectClient.new
          composer_service_client = Yade::Composer::Rest::Client::ComposerServiceClient.new
          composer_container_client = Yade::Composer::Rest::Client::ComposerContainerClient.new

          composer_project = composer_project_client.get_by_name(project_name)
          composer_services = composer_service_client.get_by_composer_project_id(composer_project.id)

          composer_service = composer_services.select { |s| s.name == service_name }.first

          composer_containers = composer_container_client.get_by_composer_service_id(composer_service.id)

          container_names = composer_containers.map(&:name).join(' ')

          begin
            cmdline = 'docker-compose logs'
            cmdline += ' -f' if options[:follow]
            cmdline += " #{container_names}"

            cmd = TTY::Command.new(uuid: false)

            cmd.run(cmdline, chdir: composer_project.install_dir)
          rescue TTY::Command::ExitError => e
            puts e
          end

          'Yade composer service successfully logged'
        end
      end
    end
  end
end