# frozen_string_literal: true

require 'mutations'

module Yadecli
  module Command
    module Composer
      class ComposerStopCommand < Mutations::Command

        required do
          string :project_name, empty: false
          string :service_name, empty: false
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          composer_project_client = Yade::Composer::Rest::Client::ComposerProjectClient.new
          composer_service_client = Yade::Composer::Rest::Client::ComposerServiceClient.new
          composer_container_client = Yade::Composer::Rest::Client::ComposerContainerClient.new

          begin
            composer_project = composer_project_client.get_by_name(project_name)
            composer_services = composer_service_client.get_by_composer_project_id(composer_project.id)

            composer_service = composer_services.select { |s| s.name == service_name }.first

            composer_containers = composer_container_client.get_by_composer_service_id(composer_service.id)

            container_names = composer_containers.map(&:name).join(' ')

            cmdline = "docker-compose stop #{container_names}"
            cmdline += " && docker-compose rm -f #{container_names}" if options[:rm]
            cmdline += ' && docker-compose down -v' if options[:down]

            cmd = TTY::Command.new(output: Yadecli.LOGGER)

            puts ''
            print "Executing command '#{cmdline}'... "

            cmd.run(cmdline, chdir: composer_project.install_dir)

            puts 'done'.colorize(:green)
          rescue TTY::Command::ExitError => e
            puts 'failed'.colorize(:red)
            puts ''
            'Stopping Yade composer service failed'
          end
          puts ''
          'Yade composer service successfully stopped'
        end
      end
    end
  end
end