# frozen_string_literal: true

require 'mutations'

module Yadecli
  module Command
    module Composer
      class ComposerSwitchCommand < Mutations::Command

        required do
          string :project_name, empty: false
          string :target_branch, empty: false
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          composer_project_client = Yade::Composer::Rest::Client::ComposerProjectClient.new

          composer_project = composer_project_client.get_by_name(project_name)

          message = "Switching to branch #{target_branch}"
          message += ' and pull changes' if options[:pull]

          print message

          cmdline = "git fetch && git checkout -B #{target_branch}"
          cmdline += " && git pull origin #{target_branch}" if options[:pull]

          begin
            cmd = TTY::Command.new(output: Yadecli.LOGGER)

            cmd.run(cmdline, chdir: composer_project.install_dir)

            puts ' done'.colorize(:green)
          rescue TTY::Command::ExitError => e
            puts ' failed'.colorize(:red)
            puts e
          end

          'Yade composer project successfully switched'
        end
      end
    end
  end
end