# frozen_string_literal: true

require 'mutations'

module Yadecli
  module Command
    module Composer
      class ComposerUninstallCommand < Mutations::Command

        required do
          string :project_name, empty: false
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          composer_project_client = Yade::Composer::Rest::Client::ComposerProjectClient.new

          composer_project = composer_project_client.get_by_name(project_name)

          answer = false
          unless options[:yes]
            prompt = TTY::Prompt.new
            answer = prompt.yes?("Do you really want to uninstall the #{composer_project.project_name} composer project?".colorize(:mode => :bold))
          end

          if options[:yes] || answer
            FileUtils.rm_rf(composer_project.install_dir)
          else
            puts 'There is nothing more I can do for you. Bye.'
            exit(1)
          end

          'Composer project successfully uninstalled'
        end
      end
    end
  end
end