# frozen_string_literal: true

require 'mutations'
require 'tty-table'

module Yadecli
  module Command
    module Host
      class HostListCommand < Mutations::Command

        #
        def execute
          host_client = Yade::Domain::Rest::Client::HostClient.new
          domain_client = Yade::Domain::Rest::Client::DomainClient.new
          role_client = Yade::Domain::Rest::Client::RoleClient.new

          hosts = host_client.list

          table = TTY::Table.new header: ['Name', 'Domain', 'Role', 'Ip', 'OsType', 'Environment']

          hosts.each do |h|
            domain_id = h.domainId
            domain = domain_client.get(domain_id)

            role_id = h.roleId
            role = role_client.get(role_id)

            table << [h.name, domain.name, role.name, h.ip, h.osType, h.environmentType]
          end

          table.render(:ascii, width: 100, resize: true, padding: [0, 1])
        end
      end
    end
  end
end