# frozen_string_literal: true

require 'mutations'
require 'net/ssh'

module Yadecli
  module Command
    module Host
      class HostProvisionCommand < Mutations::Command

        required do
          string :host_fqdn, matches: /^([a-z0-9]+(-[a-z0-9]+)*\.)+[a-z]{2,}$/
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          host_client = Yade::Domain::Rest::Client::HostClient.new

          host = host_client.host_by_fqdn(self.host_fqdn)

          username = host.username
          port = host.sshPort || 22

          Net::SSH.start(host.hostName, username, port: port) do |ssh|
            # clone or update
            cmd_line = "sudo puppet agent -t --environment=#{host.environmentType.downcase}"

            channel = ssh.open_channel do |ch|
              ch.exec cmd_line do |ch, success|
                raise "could not execute command" unless success

                # "on_data" is called when the process writes something to stdout
                ch.on_data do |c, data|
                  $stdout.print data if options[:verbose]
                end

                # "on_extended_data" is called when the process writes something to stderr
                ch.on_extended_data do |c, type, data|
                  $stderr.print data if options[:verbose]
                end

                ch.on_close { puts "done!" }
              end
            end

            channel.wait
          end
          "Successfully provisioned host #{self.host_fqdn}"
        end
      end
    end
  end
end