# frozen_string_literal: true

require 'mutations'
require 'uri'

module Yadecli
  module Command
    module Module
      class ModuleInstallCommand < Mutations::Command

        required do
          string :project_name, empty: false
        end

        optional do
          array :module_names, class: String
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          project_client = Yade::Project::Rest::Client::ProjectClient.new
          project_module_client = Yade::Project::Rest::Client::ProjectModuleClient.new

          project = project_client.project_by_name(project_name)

          if options[:all]
            project_modules = project_module_client.modules_for_project(project.id)

            project_modules.each do |project_module|
              install_module(project_module, options)
            end
          else
            self.module_names.each do |module_name|
              project_module = project_module_client.module_for_project(project.id, module_name)

              install_module(project_module, options)
            end
          end
          puts ''

          "Module(s) installed successfully"
        end

        private

        # install module
        def install_module(project_module, options)
          if project_module.installed?
            puts ''
            puts "The module with name #{project_module.name} is already installed"

            if options[:yes]
              do_update = true
            else
              prompt = TTY::Prompt.new
              do_update = prompt.yes?('Do you want to pull the changes for the project? ')
            end
          end

          cmd = TTY::Command.new(output: Yadecli.LOGGER)

          if do_update
            cmd_line = 'git pull'
            cmd.run(cmd_line, chdir: project_module.home)
          else
            vcs_client = Yade::Project::Rest::Client::VcsClient.new

            vcs = vcs_client.get(project_module.vcsId)
            cmd_line = "git clone #{vcs.url} #{project_module.home}"
            cmd.run(cmd_line)
          end
        end
      end
    end
  end
end