# frozen_string_literal: true

require 'mutations'
require 'tty-table'

module Yadecli
  module Command
    module Module
      class ModuleListCommand < Mutations::Command

        required do
          string :project_name, empty: false
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          project_client = Yade::Project::Rest::Client::ProjectClient.new
          project_module_client = Yade::Project::Rest::Client::ProjectModuleClient.new

          project = project_client.project_by_name(self.project_name)

          puts "Project: #{project.name}".colorize(:mode => :bold)

          project_modules = project_module_client.modules_for_project(project.id)

          rows = []
          project_modules.each do |m|
            module_name = m.name
            is_installed = m.installed?
            git_status = '-'
            git_status = FileUtil.git_status(m.home) if is_installed
            rows << [module_name, is_installed, git_status]
          end
          table = TTY::Table.new header: ['Module name', 'Installed', 'Git Status'], rows: rows

          table.render(:ascii, padding: [0, 1])
        end
      end
    end
  end
end