require 'mutations'
require 'uri'

module Yadecli
  module Command
    module Project
      class ProjectInstallCommand < Mutations::Command

        required do
          string :project_name, empty: false
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          project_client = Yade::Project::Rest::Client::ProjectClient.new
          vcs_client = Yade::Project::Rest::Client::VcsClient.new

          project = project_client.project_by_name(self.project_name)
          vcs = vcs_client.get(project.vcsId)

          if project.installed?
            puts "The project with name #{project_name} is already installed"

            if options[:yes]
              do_update = true
            else
              puts ''
              prompt = TTY::Prompt.new
              do_update = prompt.yes?('Do you want to pull the changes for the project? ')
            end
          end

          cmd = TTY::Command.new(output: Yadecli.LOGGER)

          if do_update
            cmd_line = 'git pull'

            cmd.run(cmd_line, chdir: project.home)

            "Yade project #{project.name} successfully pulled in #{project.home}"
          else
            cmd_line = "git clone #{vcs.url} #{project.home}"

            cmd.run(cmd_line)

            "Yade project #{project.name} successfully installed to #{project.home}"
          end
        end
      end
    end
  end
end