require 'mutations'
require 'uri'

module Yadecli
  module Command
    module Project
      class ProjectSetupCommand < Mutations::Command

        required do
          string :project_name, empty: false
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          project_client = Yade::Project::Rest::Client::ProjectClient.new
          sdk_package_client = Yade::Project::Rest::Client::SdkPackageClient.new
          rvm_runtime_client = Yade::Project::Rest::Client::RvmRuntimeClient.new
          nvm_runtime_client = Yade::Project::Rest::Client::NvmRuntimeClient.new
          pyenv_runtime_client = Yade::Project::Rest::Client::PyenvRuntimeClient.new

          project = project_client.project_by_name(self.project_name)

          sdk_packages = sdk_package_client.sdk_packages_for_project(project.id)

          # sdk
          puts ''
          puts 'Setup sdk packages:'.colorize(:mode => :bold)
          sdk_packages.each do |sdkp|
            SdkUtil.install_candidate(sdkp.name, sdkp.version)
          end

          # rvm
          rvm_runtime = rvm_runtime_client.get(project.id)
          RvmUtil.setup_rvm(project, rvm_runtime)

          # nvm
          nvm_runtime = nvm_runtime_client.get(project.id)
          NvmUtil.setup_nvm(project, nvm_runtime)

          # pyenv
          pyenv_runtime = pyenv_runtime_client.get(project.id)
          PyenvUtil.setup_pyenv(project, pyenv_runtime)

          # direnv
          puts ''
          puts 'Setup direnv:'.colorize(mode: :bold)
          puts ' ↳ Create .envrc'
          File.open("#{project.home}/.envrc", 'w') do |f|
            f.puts("export PROJECT_ID=#{project.name}")
            f.puts("export PROJECT_HOME=#{project.home}")
            f.puts("export PROJECT_SRC_HOME=#{project.home}/src")
          end
          puts ''

          "Yade project #{project.name} successfully setup"
        end
      end
    end
  end
end