require 'mutations'
require 'uri'

module Yadecli
  module Command
    module Project
      class ProjectStartCommand < Mutations::Command

        required do
          string :project_name, empty: false
        end

        optional do
          integer :selection, max: 5
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          project_client = Yade::Project::Rest::Client::ProjectClient.new

          project = project_client.project_by_name(project_name)

          puts " ↳ Name: #{project.name}"
          puts " ↳ Home: #{project.home}"

          prompt = TTY::Prompt.new

          ide_name = if project.ideType == 'IDEA'
                       'Intellij Idea'
                     elsif project.ideType == 'RUBYMINE'
                       'Intellij Rubymine'
                     else
                       'Unknown'
                     end

          puts ''
          if selection.nil?
            answer = prompt.select('What do you want to do?'.colorize(mode: :bold)) do |menu|
              menu.choice '1) Terminal setup', 1
              menu.choice '2) Multiplexer Terminal setup', 2
              if ide_name == 'Unknown'
                menu.choice "3) Start IDE #{ide_name}", 3, disabled: '(n.a.)'
              else
                menu.choice "3) Start IDE #{ide_name}", 3
              end
              menu.choice '4) Start Editor', 4
              menu.choice '5) Quit', 5
            end
          else
            answer = Integer(selection)
          end

          result_json = "#{Yade::Common::Config::AppConfig[:yade_home]}/result.json"

          case answer
          when 1
            # puts 'Setting up Terminal'
            # puts ''

            ProjectStartResponse.new(project: project, project_home: project.home, selection: answer)
                       .write(result_json)

            "Yade project #{project.name} terminal setup successfully"
          when 2
            # puts 'Setting up Multiplexer Terminal'
            # puts ''

            tmux_config = prompt.select('Select the tmux profile?'.colorize(mode: :bold)) do |menu|
              Dir.glob("#{project.home}/tmuxinator-*.yml").each do |tmux_config|
                menu.choice File.basename(tmux_config, '.yml')[11..-1], tmux_config
              end
            end

            dir = File.dirname(tmux_config)
            FileUtils.ln tmux_config, "#{dir}/.tmuxinator.yml", force: true

            ProjectStartResponse.new(project: project, project_home: project.home, selection: answer)
                       .write(result_json)

            "Yade project #{project.name} multiplexer terminal setup successfully"
          when 3
            puts "Start IDE #{ide_name}"

            ProjectStartResponse.new(project: project, project_home: project.home, selection: answer)
                       .write(result_json)

            "Yade project #{project.name} ide started successfully"
          when 4
            puts 'Start Editor'

            ProjectStartResponse.new(project: project, project_home: project.home, selection: answer)
                       .write(result_json)

            "Yade project #{project.name} editor started successfully"
          when 5
            ProjectStartResponse.new(project: project, project_home: project.home, selection: answer)
                       .write(result_json)

            'Bye'
          else
            'Unknown'
          end
        end
      end
    end
  end
end