require 'mutations'
require 'uri'

module Yadecli
  module Command
    module Project
      class ProjectUninstallCommand < Mutations::Command

        required do
          string :project_name, empty: false
        end

        optional do
          hash :options do
            string :* # Allows any key to pass through. Useful for dynamic key / value objects
          end
        end

        #
        def execute
          project_client = Yade::Project::Rest::Client::ProjectClient.new

          project = project_client.project_by_name(self.project_name)

          unless project.installed?
            puts "The project with name #{self.project_name} is not installed"
            exit 1
          end

          if options[:yes]
            really_uninstall = true
          else
            prompt = TTY::Prompt.new
            really_uninstall = prompt.yes?("Do you really want to uninstall the project #{project.name} and all it's modules? ")
          end

          FileUtils.rm_rf(project.home) if really_uninstall

          "Yade project #{project.name} successfully uninstalled from #{project.home}"
        end
      end
    end
  end
end