# frozen_string_literal: true

require 'colorize'
require 'artii'
require 'tty-command'

# cli util
class FileUtil
  # all methods in this block are static
  class << self

    # git status
    def git_status(dir)
      cmd = TTY::Command.new(output: Yadecli.LOGGER)

      out, err = cmd.run('git fetch', chdir: dir)
      out, err = cmd.run('git status -uno', chdir: dir)

      if out.include? 'Your branch is ahead'
        GitStatus::NEEDS_PUSH
      elsif out.include? 'Your branch is behind'
        GitStatus::NEEDS_PULL
      else
        GitStatus::UP_TO_DATE
      end
    end

    def git_current_branch(dir)
      cmd = TTY::Command.new(output: Yadecli.LOGGER)
      out, err = cmd.run('git rev-parse --abbrev-ref HEAD', chdir: dir)

      out.chomp
    end

    # scripts dir
    def script_dir
      script_dir = File.join(File.dirname(File.expand_path(__FILE__)), '../../../scripts')

      script_dir
    end

    def script_path(script_name)
      "#{script_dir}/#{script_name}"
    end
  end
end